# -*- coding: utf-8 -*-

import logging
import requests

from .compat import quote
from .fwi_base import Fwi


class Player(Fwi):
    """wraps player commands"""

    def __init__(self, **kwargs):
        super(Player, self).__init__(**kwargs)

        self.url_schema = 'http://{0}:{1}/player/command/RunScript?1='.format(self.host,
                                                                              self.port)
        if self.debug:
            logging.debug('Url Schema: {0}'.format(self.url_schema))

    def set_variable(self, name, value):
        name = quote(str(name))
        value = quote(str(value))

        script_schema = 'Player.SetVariable({0}, "{1}");'.format(name, value)

        url = self.url_schema + script_schema
        resp = self._make_request(url)

        if self.debug:
            logging.debug('Script: {0}'.format(script_schema))

        return {'name': name,
                'value': value,
                'resp': resp}

    def play_content(self, name, value):
        name = quote(str(name))
        value = quote(str(value))

        script_schema = 'Template.PlayContent({0}, "{1}")'.format(name, value)

        url = self.url_schema + script_schema
        resp = self._make_request(url)

        if self.debug:
            logging.debug('Script: {0}'.format(script_schema))

        return {'name': name,
                'value': value,
                'resp': resp}

    def play_template(self, name):
        name = quote(name)

        script_schema = 'Player.PlayTemplate({0})'.format(name)

        url = self.url_schema + script_schema
        resp = self._make_request(url)

        if self.debug:
            logging.debug('Script: {0}'.format(script_schema))

        return {'name': name,
                'resp': resp}



# -*- coding: utf-8 -*-

import logging
import requests

from requests.auth import HTTPBasicAuth

class Fwi(object):
    """Base class for all fwi objects"""

    def __init__(self, **kwargs):
        self.host = kwargs.get('host', '127.0.0.1')
        self.debug = kwargs.get('debug')
        self.port = str(kwargs.get('port', '10561'))
        self.username = kwargs.get('username')
        self.password = kwargs.get('password')

    def _make_request(self, payload):
        resp = requests.get(payload, auth=HTTPBasicAuth(self.username, self.password))
        return resp


# -*- coding: utf-8 -*-

#    ___        _ ___
#   | __|_ __ _(_) _ \_  _
#   | _|\ V  V / |  _/ || |
#   |_|  \_/\_/|_|_|  \_, |
#                     |__/

"""
Fwipy - Python Wrapper for Content Player Socket Operations
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    >>> from fwipy import Player

    >>> player = Player(host='127.0.0.1',
                port=10561,
                username='admin',
                password='fourwinds')

    >>> player.set_variable('foo', 'bar')

:copyright: (c) 2017 by Erin O'Connell.
:license: Apache 2.0, see LICENSE for more details.
"""

from .player import Player
from .readerId import ReaderId
from .template import Template



#   ___________    __    ____  __  .______   ____    ____
#  |   ____\   \  /  \  /   / |  | |   _  \  \   \  /   /
#  |  |__   \   \/    \/   /  |  | |  |_)  |  \   \/   /
#  |   __|   \            /   |  | |   ___/    \_    _/
#  |  |       \    /\    /    |  | |  |          |  |
#  |__|        \__/  \__/     |__| | _|          |__|


__title__ = 'fwipy'
__description__ = 'Fwipy - Python Wrapper for Content Player Socket Operations'
__url__ = 'https://github.com/FourWindsInteractive/fwipy'
__version__ = '0.0.1.dev0'
__author__ = "Erin O'Connell"
__author_email__ = 'erin.oconnell@fourwindsinteractive.com'
__license__ = 'Apache 2.0'
__copyright__ = "Copyright 2017 Erin O'Connell"
__download_url__ = 'https://github.com/fourwindsinteractive/fwipy/archive/{0}.tar.gz'.format(__version__)


# -*- coding: utf-8 -*-

import logging
import requests

from .compat import quote
from .fwi_base import Fwi

class ReaderId(Fwi):
    """Send a request to trigger a playtrigger inside of content player"""

    def __init__(self, **kwargs):
        super().__init__(**kwargs)

        self.url_schema = 'http://{0}:{1}/player/readerId/'.format(self.host, self.port)

        if self.debug:
            logging.debug('Url Schema: {0}'.format(url_schema))

    def trigger_id(self, id):
        """Accepts a readerId to send to content player, returns a requests response object"""
        url = self.url_schema + quote(str(id))

        resp = self._make_request(url)

        if self.debug:
            logging.debug('{0} triggered'.format(url))

        return {'id': id,
                'resp': resp}





import io
import os
import sys
from shutil import rmtree

from setuptools import setup, Command

# Package meta-data.
NAME = 'fwipy'
DESCRIPTION = 'Fwipy - Python Wrapper for Content Player Socket Operations'
URL = 'https://github.com/fourwindsinteractive/fwipy'
EMAIL = 'erin.oconnell@fourwindsinteractive.com'
AUTHOR = "Erin O'Connell"
VERSION = '0.1.3'

# What packages are required for this module to be executed?
REQUIRED = [
    'requests'
]

# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License, remember to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

# Import the README and use it as the long-description.
# Note: this will only work if 'README.rst' is present in your MANIFEST.in file!
with io.open(os.path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = '\n' + f.read()

class UploadCommand(Command):
    """Support setup.py upload."""

    description = 'Build and publish the package.'
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('\033[1m{0}\033[0m'.format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'dist'))
        except OSError:
            pass

        self.status('Building Source and Wheel (universal) distribution…')
        os.system('{0} setup.py sdist bdist_wheel --universal'.format(sys.executable))

        self.status('Uploading the package to PyPi via Twine…')
        os.system('twine upload dist/*')

        self.status('Publishing git tags…')
        os.system('git tag v{0}'.format(VERSION))
        # os.system('git push --tags')

        sys.exit()


# Where the magic happens:
setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=long_description,
    author=AUTHOR,
    author_email=EMAIL,
    url=URL,
    python_requires='>=3.6.0',
    # If your package is a single module, use this instead of 'packages':
    # py_modules=['requests_xml'],
    packages= ['fwipy'],
    install_requires=REQUIRED,
    include_package_data=True,
    license='Apache 2.0',
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
    ],
    # $ setup.py publish support.
    cmdclass={
        'upload': UploadCommand,
    },
)
